<?php

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly.

class HTMegaBuilder_Admin_Settings {

    private $settings_api;

    function __construct() {
        add_filter( 'htmega_admin_fields_sections', [ $this, 'fields_section' ], 10, 1 );

        $this->settings_api = new HTmega_Settings_API();
        add_action( 'admin_init', [ $this, 'admin_init' ] );
        add_action( 'admin_menu', [ $this, 'admin_menu' ], 224 );
    }

    // Admin Initialize
    function admin_init() {

        //set the settings
        $this->settings_api->set_sections( $this->admin_get_settings_sections() );
        $this->settings_api->set_fields( $this->admin_fields_settings() );

        //initialize settings
        $this->settings_api->admin_init();
    }

    // Plugins menu Register
    function admin_menu() {

        add_submenu_page(
            'htmega-addons', 
            esc_html__( 'HT Builder', 'htmega-pro' ),
            esc_html__( 'HT Builder', 'htmega-pro' ), 
            'manage_options', 
            'htmegabuilder', 
            [ $this, 'plugin_page' ] 
        );

    }

     /**
     * Admin Fields Section Route
     *
     * @param [array] $sections
     * @return void
     */
    public function fields_section( $sections ){

        $sections['themebuilder'] = array(
            'id'    => 'htmega_themebuilder_element_tabs',
            'title' => esc_html__( 'Theme Builder', 'htmega-addons' ),
            'icon'  => 'htmega htmega-themebuilder',
            'content' => [
                'column' => 3,
                'title' => __( 'Theme Builder Widget List', 'htmega-addons' ),
                'desc'  => __( 'Freely use these elements to create your site. You can enable which you are not using, and, all associated assets will be disable to improve your site loading speed.', 'htmega-addons' ),
            ],
            ''
        );

        return $sections;

    }

    // Options page Section register
    function admin_get_settings_sections() {
        $sections = array(

            array(
                'id'    => 'htmegabuilder_templatebuilder_tabs',
                'title' => esc_html__( 'Theme Builder', 'htmega-pro' )
            ),

        );
        return $sections;
    }

    // Options page field register
    protected function admin_fields_settings() {

        $settings_fields = array(
            
            'htmegabuilder_templatebuilder_tabs' => array(

                array(
                    'name'    => 'single_blog_page',
                    'label'   => __( 'Single Blog Template.', 'htmega-pro' ),
                    'desc'    => __( 'You can select Single blog page from here.', 'htmega-pro' ),
                    'type'    => 'select',
                    'default' => '0',
                    'options' => htmega_elementor_template()
                ),

                array(
                    'name'    => 'archive_blog_page',
                    'label'   => __( 'Blog Template.', 'htmega-pro' ),
                    'desc'    => __( 'You can select blog page from here.', 'htmega-pro' ),
                    'type'    => 'select',
                    'default' => '0',
                    'options' => htmega_elementor_template()
                ),

                array(
                    'name'    => 'header_page',
                    'label'   => __( 'Header Template.', 'htmega-pro' ),
                    'desc'    => __( 'You can select header template from here.', 'htmega-pro' ),
                    'type'    => 'select',
                    'default' => '0',
                    'options' => htmega_elementor_template()
                ),

                array(
                    'name'    => 'footer_page',
                    'label'   => __( 'Footer Template.', 'htmega-pro' ),
                    'desc'    => __( 'You can select footer template from here.', 'htmega-pro' ),
                    'type'    => 'select',
                    'default' => '0',
                    'options' => htmega_elementor_template()
                ),

                array(
                    'name'    => 'search_page',
                    'label'   => __( 'Search Page Template.', 'htmega-pro' ),
                    'desc'    => __( 'You can select search page from here.', 'htmega-pro' ),
                    'type'    => 'select',
                    'default' => 'select',
                    'options' => htmega_elementor_template()
                ),

                array(
                    'name'    => 'error_page',
                    'label'   => __( '404 Page Template.', 'htmega-pro' ),
                    'desc'    => __( 'You can select 404 page from here.', 'htmega-pro' ),
                    'type'    => 'select',
                    'default' => '0',
                    'options' => htmega_elementor_template()
                ),

                array(
                    'name'    => 'coming_soon_page',
                    'label'   => __( 'Coming Soon Page Template.', 'htmega-pro' ),
                    'desc'    => __( 'You can select coming soon page from here.', 'htmega-pro' ),
                    'type'    => 'select',
                    'default' => '0',
                    'options' => htmega_elementor_template()
                ),

            ),


        );
        
        return array_merge( $settings_fields );
    }

    // Admin Menu Page Render
    function plugin_page() {

        echo '<div class="wrap">';
            echo '<h2>'.esc_html__( 'HT Builder Settings','htmega-pro' ).'</h2>';
            $this->save_message();
            $this->settings_api->show_navigation();
            $this->settings_api->show_forms();
        echo '</div>';

    }

    // Save Options Message
    function save_message() {
        if( isset($_GET['settings-updated']) ) { ?>
            <div class="updated notice is-dismissible"> 
                <p><strong><?php esc_html_e('Successfully Settings Saved.', 'htmega-pro') ?></strong></p>
            </div>
            <?php
        }
    }


}

new HTMegaBuilder_Admin_Settings();